@@ -550,7 +550,7 @@ class ExecutionServer(BaseServer):
             LOGGER.critical("No average speed to report yet.")
             
     def executeJobs(self, data=None):
-        for i in range(0, 10):            
+        for i in range(0, 100):            
             if len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
                 job = self.job_queue.pop(0)
                 exposed_function = job["exposed_function"]
@@ -570,7 +570,7 @@ class ExecutionServer(BaseServer):
                 d.addCallback(self._setNextRequest, uuid, exposed_function["interval"], function_name)
             else:
                 return
-        reactor.callLater(0, self.executeJobs)
+        reactor.callLater(0.01, self.executeJobs)
             
     def _callExposedFunction(
         self, 
